==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/firstrunwizard/l10n/nl.php <==
<?php
$TRANSLATIONS = array(
"A safe home for all your data" => "Een veilig thuis voor al uw gegevens",
"Access & share your files, calendars, contacts, mail & more from any device, on your terms" => "Bereik & deel uw bestanden, agenda's, contactpersonen, e-mail & meer, vanaf elk apparaat, op uw eigen voorwaarden",
"Get the apps to sync your files" => "Download de apps om bestanden te synchen",
"Desktop client" => "Desktop client",
"Android app" => "Android app",
"iOS app" => "iOS app",
"Connect your desktop apps to %s" => "Verbind uw desktop apps met %s",
"Connect your Calendar" => "Verbindt uw agenda",
"Connect your Contacts" => "Verbindt uw contactpersonen",
"Documentation" => "Documentatie",
"Access files via WebDAV" => "Benader bestanden via WebDAV",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Er is meer informatie in de <a target=\"_blank\" href=\"%s\">documentatie</a> en op onze  <a target=\"_blank\" href=\"http://owncloud.org\">website</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files.\n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Als u ownCloud leuk vindt,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is is mooi open software om ue bestanden te synchroniseren en delen.\n\t\tU kunt het gratis ophalen van  http://owncloud.org\">\n\t\tbeveel het aan bij uw vrienden</a>\n\ten  <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">verkondig het woord</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-9.1.3-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/firstrunwizard/l10n/nl.php <==
<?php
$TRANSLATIONS = array(
"A safe home for all your data" => "Een veilig thuis voor al uw gegevens",
"Access & share your files, calendars, contacts, mail & more from any device, on your terms" => "Bereik & deel uw bestanden, agenda's, contactpersonen, e-mail & meer, vanaf elk apparaat, op uw eigen voorwaarden",
"Get the apps to sync your files" => "Download de apps om bestanden te synchen",
"Desktop client" => "Desktop client",
"Android app" => "Android app",
"iOS app" => "iOS app",
"Connect your desktop apps to %s" => "Verbind uw desktop apps met %s",
"Connect your Calendar" => "Verbind uw agenda",
"Connect your Contacts" => "Verbind uw contactpersonen",
"Documentation" => "Documentatie",
"Access files via WebDAV" => "Benader bestanden via WebDAV",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Er is meer informatie in de <a target=\"_blank\" href=\"%s\">documentatie</a> en op onze  <a target=\"_blank\" href=\"http://owncloud.org\">website</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files.\n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Als u ownCloud leuk vindt,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is is mooi open software om ue bestanden te synchroniseren en delen.\n\t\tU kunt het gratis ophalen van  http://owncloud.org\">\n\t\tbeveel het aan bij uw vrienden</a>\n\ten  <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">verkondig het woord</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
